Crate tslocal

Crate tslocal 

Client library for the Tailscale Local API.

Structs

Client
Client for the Tailscale Local API.
ClientVersion
ClientVersion is information about the latest client version that’s available for the client (and whether they’re already running it).
ExitNodeStatus
ExitNodeStatus describes the current exit node.
HTTPHandler
HTTPHandler is either a path or a proxy to serve.
Hostinfo
Hostinfo contains a summary of a Tailscale host.
Location
Location represents geographical location data about a Tailscale host. Location is optional and only set if explicitly declared by a node.
NetInfo
NetInfo contains information about the host’s network state.
Node
Node is a Tailscale device in a tailnet.
PeerStatus
PeerStatus describes a peer node and its current state. WARNING: The fields in PeerStatus are merged by the AddPeer method in the StatusBuilder. When adding a new field to PeerStatus, you must update AddPeer to handle merging the new field. The AddPeer function is responsible for combining multiple updates to the same peer, and any new field that is not merged properly may lead to inconsistencies or lost data in the peer status.
Resolver
Resolver is the configuration for one DNS resolver.
ServeConfig
ServeConfig is the JSON type stored in the StateStore for StateKey “_serve/$PROFILE_ID” as returned by ServeConfigKey.
Service
Service represents a service running on a node.
ServiceConfig
ServiceConfig contains the config information for a single service. it contains a bool to indicate if the service is in Tun mode (L3 forwarding). If the service is not in Tun mode, the service is configured by the L4 forwarding (TCP ports) and/or the L7 forwarding (http handlers) information.
Status
Status represents the entire state of the IPN network.
TCPPortHandler
TCPPortHandler describes what to do when handling a TCP connection.
TPMInfo
TPMInfo contains information about a TPM 2.0 device present on a node. All fields are read from TPM_CAP_TPM_PROPERTIES, see Part 2, section 6.13 of https://trustedcomputinggroup.org/resource/tpm-library-specification/.
TailnetStatus
TailnetStatus is information about a Tailscale network (“tailnet”).
TransportConfig
Configuration for connecting to tailscaled.
UserProfile
A UserProfile is display-friendly data for a [User]. It includes the LoginName for display purposes but not the Provider. It also includes derived data from one of the user’s logins.
WebServerConfig
WebServerConfig describes a web server’s configuration.
WhoIsResponse
WhoIsResponse is the JSON type returned by tailscaled debug server’s /whois?ip=$IP handler. In successful whois responses, Node and UserProfile are never nil.

Enums

Error
Root error type for the Tailscale Local API client.