ClientVersion

Struct ClientVersion 

pub struct ClientVersion {
    pub running_latest: bool,
    pub latest_version: String,
    pub urgent_security_update: bool,
    pub notify: bool,
    pub notify_url: String,
    pub notify_text: String,
}
ClientVersion is information about the latest client version that’s available for the client (and whether they’re already running it).

It does not include a URL to download the client, as that varies by platform.

Fields

running_latest: bool

RunningLatest is true if the client is running the latest build.

latest_version: String

LatestVersion is the latest version.Short (“1.34.2”) version available for download for the client’s platform and packaging type. It won’t be populated if RunningLatest is true.

urgent_security_update: bool

UrgentSecurityUpdate is set when the client is missing an important security update. That update may be in LatestVersion or earlier. UrgentSecurityUpdate should not be set if RunningLatest is false.

notify: bool

Notify is whether the client should do an OS-specific notification about a new version being available. This should not be populated if RunningLatest is true. The client should not notify multiple times for the same LatestVersion value.

notify_url: String

NotifyURL is a URL to open in the browser when the user clicks on the notification, when Notify is true.

notify_text: String

NotifyText is the text to show in the notification, when Notify is true.