pub struct TCPPortHandler {
pub https: bool,
pub http: bool,
pub tcp_forward: String,
pub terminate_tls: String,
pub proxy_protocol: i64,
}Expand description
TCPPortHandler describes what to do when handling a TCP connection.
Fields
https: boolHTTPS, if true, means that tailscaled should handle this connection as an HTTPS request as configured by ServeConfig.Web.
It is mutually exclusive with TCPForward.
http: boolHTTP, if true, means that tailscaled should handle this connection as an HTTP request as configured by ServeConfig.Web.
It is mutually exclusive with TCPForward.
tcp_forward: StringTCPForward is the IP:port to forward TCP connections to. Whether or not TLS is terminated by tailscaled depends on TerminateTLS.
It is mutually exclusive with HTTPS.
terminate_tls: StringTerminateTLS, if non-empty, means that tailscaled should terminate the TLS connections before forwarding them to TCPForward, permitting only the SNI name with this value. It is only used if TCPForward is non-empty. (the HTTPS mode uses ServeConfig.Web)
proxy_protocol: i64ProxyProtocol indicates whether to send a PROXY protocol header before forwarding the connection to TCPForward.
This is only valid if TCPForward is non-empty.