pub struct ServiceConfig {
pub tcp: HashMap<u16, TCPPortHandler>,
pub web: HashMap<String, WebServerConfig>,
pub tun: bool,
}Expand description
ServiceConfig contains the config information for a single service. it contains a bool to indicate if the service is in Tun mode (L3 forwarding). If the service is not in Tun mode, the service is configured by the L4 forwarding (TCP ports) and/or the L7 forwarding (http handlers) information.
Fields
tcp: HashMap<u16, TCPPortHandler>TCP are the list of TCP port numbers that tailscaled should handle for the Tailscale IP addresses. (not subnet routers, etc)
web: HashMap<String, WebServerConfig>Web maps from “$SNI_NAME:$PORT” to a set of HTTP handlers keyed by mount point (“/”, “/foo”, etc)
tun: boolTun determines if the service should be using L3 forwarding (Tun mode).